@@ -1274,16 +1274,6 @@ Def-dict: a dictionary of dictionaries
                             wMsg = str(exc)
                             raise self.ParamError(self.__MakeErrorMsg(Type="ErrMsg",Msg=wMsg,Path=a,FullPath=n,Param=o)) from None
                         self.__AssignImportValues(wGlobDict, FileName=str(n))
-                        
-                        # try:
-                        #     wDict = wGlobDict[self.__Prefix]
-                        # except:
-                        #     wDict = {}
-                        # for k in self.__WorkDict.keys():
-                        #     try:
-                        #         self.__WorkDict[k] = wDict[k]
-                        #     except:
-                        #         pass
                     else:
                         raise self.ParamError(self.__MakeErrorMsg(Type="NoFile",Path=a,FullPath=n,Param=o)) from None
                 else:
@@ -1391,32 +1381,33 @@ Def-dict: a dictionary of dictionaries
             self.ParamError: if values do not meet the limits
         """        
         try:
-            wDict = wGlobDict[self.__Prefix]
+            wDict = wGlobDict[self.__Prefix]    # versuche die gewünschten Werte zu erhalten
         except:
-            wDict = {}
-        for k in self.__WorkDict.keys():
+            wDict = {}  # es sind keine Angaben für diesen Prefix in der Datei -> Nichts zu setzen
+            
+        for k in self.__WorkDict.keys():        # versuche Daten für all unsere Keys zu bekommen
             IsOk = True
             try:
                 iVal = wDict[k]
             except:
-                IsOk = False
+                IsOk = False                    # keine Daten für diesen Key
             if IsOk:
-                NameStr = f'{k} (Imported from {FileName} [{self.__Prefix}])'
-                if isinstance(iVal,list) or isinstance(iVal,tuple):
-                     for iVs in iVal:
+                NameStr = f'{k} (Imported from {FileName} [{self.__Prefix}])'   # Bezeichnung für ev. Fehlermeldungen
+                if isinstance(iVal,(list, tuple)):      # dind die Daten ein Array?
+                     for iVs in iVal:                   # Löse das Array auf
                         Res = self.__CheckOption(k, NameStr, self.__Definition[k], iVs)
                         if not Res is None:
                             raise self.ParamError(Res)
                 else:    
                     Res = self.__CheckOption(k, NameStr, self.__Definition[k], iVal)
-                if Res is not None:
-                    raise self.ParamError(Res)
-                    # self.__WorkDict[k] = iVal
+                if Res is not None:                     # der übergebene Wert war ungültig
+                        raise self.ParamError(Res)
         for n,c in self.__Children.items():
-            c.__AssignImportValues(wGlobDict,FileName=FileName)
+            c.__AssignImportValues(wGlobDict,FileName=FileName) # löse auch für alle Child-Klassen auf
 
     def __GetOptList(self,Name: str) -> str:
-        """ liste der möglichen Parameter eines Keys"""
+        """Liste der möglichen Commandline-Parameter eines Keys
+        Es werden sowohl alle Kurz- als auch alle Langforman zurückgegeben """
         w = self.__Definition[Name]
         Erg = ""
         if self.__WorkPars['shortpar'] in w.keys():
@@ -1434,7 +1425,9 @@ Def-dict: a dictionary of dictionaries
         return Erg
 
     def __CheckOption(self, ParName: str, ParKey: str, wPar: dict, a: str) -> str:
-        """[summary]
+        """Prüft ob der angegebene Inhalt für diesen Parameter gültig ist
+        Wenn Ja: Der Wert wird in das Ergebnisdictionary geschrieben und "None" zurückgegeben.
+        Wenn Nein: Das Ergebnisdictionary ist unverändert, Rückgabe ist die Fehlermeldung
 
         Args:
             ParName (string): Name of the parameter (index in class as dictionary)
@@ -1459,6 +1452,7 @@ Def-dict: a dictionary of dictionaries
             if wMulti:
                 if ParName not in self:
                    self.__WorkDict[ParName] = [] 
+            a = str(a)
             try:
                 ll = wPar[self.__WorkPars['lowlimit']]
                 if a < ll:
@@ -1486,7 +1480,7 @@ Def-dict: a dictionary of dictionaries
             try:
                 n = int(a)
             except:
-                return f"Value {a} for parameter {ParKey} is not an integer"
+                return f"Value {a} for parameter {ParKey} is not a valid integer"
             try:
                 ll = wPar[self.__WorkPars['lowlimit']]
                 if n < ll:
@@ -1513,7 +1507,7 @@ Def-dict: a dictionary of dictionaries
             try:
                 n = int(a)
             except:
-                return f"Value {a} for parameter {ParKey} is not an integer"
+                return f"Value {a} for parameter {ParKey} is not a valid integer"
             if ParName in self.__WorkDict:
                 self.__WorkDict[ParName] += n
             else:
@@ -1529,7 +1523,7 @@ Def-dict: a dictionary of dictionaries
             try:
                 n = float(a)
             except:
-                return f"Value {a} for parameter {ParKey} is not floating point"
+                return f"Value {a} for parameter {ParKey} is not a valid floating point"
             try:
                 ll = wPar[self.__WorkPars['lowlimit']]
                 if n < ll:
@@ -1551,8 +1545,10 @@ Def-dict: a dictionary of dictionaries
 # Boolean
 #-------------------------
         if wMod == self.__WorkModes['bool']:
-            if type(a) == bool:
-                a = 't' if a else 'f'
+            try:
+                a = str(a)
+            except:
+                a = 'F'
             try:
                 n = a.lower()[0]
             except:
@@ -1560,7 +1556,7 @@ Def-dict: a dictionary of dictionaries
             if n in 'jyt1':
                 self.__WorkDict[ParName] = True
                 return None
-            if n in 'n0f':
+            if n in 'nf0':
                 self.__WorkDict[ParName] = False
                 return None
             return f"Value {a} for parameter {ParKey} is not valid"
@@ -1571,6 +1567,9 @@ Def-dict: a dictionary of dictionaries
             if wMulti:
                 if ParName not in self:
                    self.__WorkDict[ParName] = [] 
+            a = str(a).strip()
+            if len(a) == 0:
+                return f"The name {a} for parameter {ParKey} is not a valid path"
             if a[0] != "/":
                 a = self.__MyPwd + "/" + a
             try:
@@ -1594,6 +1593,9 @@ Def-dict: a dictionary of dictionaries
             if wMulti:
                 if ParName not in self:
                    self.__WorkDict[ParName] = [] 
+            a = str(a).strip()
+            if len(a) == 0:
+                return f"The name {a} for parameter {ParKey} is not a valid path"
             if a[0] != "/":
                 a = self.__MyPwd + "/" + a
             try:
@@ -1617,6 +1619,7 @@ Def-dict: a dictionary of dictionaries
             if wMulti:
                 if ParName not in self:
                    self.__WorkDict[ParName] = [] 
+            a = str(a).strip()
             if a != '':
                 if a[0] != "/":
                     a = self.__MyPwd + "/" + a
@@ -1630,8 +1633,6 @@ Def-dict: a dictionary of dictionaries
                 self.__WorkDict[ParName].append(n)
             else:
                 self.__WorkDict[ParName] = n
-            return None
-        
         return None
 
     def GetRemainder(self) -> list:
